// java wrapper for vtkRenderLargeImage object
//

package vtk;
import vtk.*;

public class vtkRenderLargeImage extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetMagnification_2(int id0);
  public void SetMagnification(int id0)
    { SetMagnification_2(id0); }

  private native int GetMagnification_3();
  public int GetMagnification()
    { return GetMagnification_3(); }

  private native void SetInput_4(vtkRenderer id0);
  public void SetInput(vtkRenderer id0)
    { SetInput_4(id0); }

  private native long GetInput_5();
  public vtkRenderer GetInput() {
    long temp = GetInput_5();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_6();
  public vtkImageData GetOutput() {
    long temp = GetOutput_6();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkRenderLargeImage() { super(); }

  public vtkRenderLargeImage(long id) { super(id); }
  public native long   VTKInit();

}
